@@ -29,8 +29,8 @@ temperatures_folders = read.read_post_proc(input_file)[10]
 
 
 tot_atoms_uc = int(np.sum(n_atom_unit_cell)) 
-Nqpoints, qpoints_scaled, ks, freqs_disp, eigvecs, distances, Hk = read.read_phonopy(file_eigenvectors, tot_atoms_uc)
-Ruc, R0, masses, masses_for_animation = read.read_SPOSCAR_and_masses(file_SPOSCAR, n_atom_unit_cell, n_atom_unit_cell, Masses)  
+Nqpoints, qpoints_scaled, ks, freqs_disp, eigvecs_phonopy, distances, Hk = read.read_phonopy(file_eigenvectors, tot_atoms_uc)
+SCell, Ruc, R0, masses, masses_for_animation = read.read_SPOSCAR_and_masses(file_SPOSCAR, n_atom_unit_cell, n_atom_unit_cell, Masses)  
 #### =============================================================================
 
 for mode in plot_types:
@@ -204,7 +204,6 @@ for mode in plot_types:
                             mm = modes[b]
                             ZQS_proj[:,b,i] = Zq[:,mm+1]
                     count = count + 1
-    
         plot.plot_k2(freq,ZQS,ZQS_proj, x_labels,[freqs_from_disp],max_Z,modes, freq_res, title=['0K dispersion'])
 
     if(mode==6):
@@ -222,7 +221,7 @@ for mode in plot_types:
             for j in range(len(ks_path)):
                 if(np.allclose(qpoint, ks_path[j]) and ((qpoint.tolist() not in accepted_qpoints) or i==j)): #è un completo delirio
                     accepted_qpoints.append(qpoint.tolist())
-                    eigvec = eigvecs[i]
+                    eigvec = eigvecs_phonopy[i]
                     freq_disp = freqs_disp[i]
                     Zq = np.genfromtxt('Zqs',skip_header=to_skip+1, max_rows=meta)
                     for b in range(len(modes)):
@@ -231,6 +230,145 @@ for mode in plot_types:
         
         
         
+    if(mode==7):
+        print('WARNING: atm this only works for cubic crystals!')
+        # take the path the user inputs and find all the k points you can plot
+        ks_path, x_labels, distances = read.read_path(kinput, Nqpoints, labels, Hk) 
+        
+        c_A_to_B = 1.88973 #conversion to Bohrs
+        Hk = Hk/(2*np.pi) #if you use Thz as frequencies, you have to use 1/B as k, without 2 pi
+        Hk = Hk*c_A_to_B #if you wanna use the 1/100 conv factor later, you need Angstrom
+        
+        #find the closest qpoints for EC
+        dirs_C11 = [[1,0,0],[0,1,0],[0,0,1]]
+        dirs_C12_C44 = [[1,1,0],[1,0,1],[0,1,1]]
+        ampl = 10
+        
+        A1, A2, A3 = SCell[0,:], SCell[1,:], SCell[2,:]
+        V = np.dot(A1, np.cross(A2,A3))
+        print('The volume of the supercell is ', V, 'Bohr^3')
+        print('NB: if you run a NPE simulation, you better use the average NPE volume!')
+        conv_to_gcm3 = 11.2059 #convert amu/B^3 to g/cm^3
+        M_tot = np.sum(masses)/3
+        rho = M_tot/V*conv_to_gcm3
+        print('The density is ',rho, ' g/cm^3\n')
+        
+        conv_factor = 1/100        
+        
+        accepted_qpoints = []
+        for i in range(1,len(ks_path)-1):
+            eigvec_q = eigvecs_phonopy[i]
+            
+            qpoint_sc = ks_path[i]
+            qpoint_sc_prev = ks_path[i-1]
+            direc = np.abs(np.dot(Hk, qpoint_sc - qpoint_sc_prev))
+            direc_sc = np.round(direc/direc.max(),2)
+
+                
+            to_skip = (4)*i
+            qpoint = np.genfromtxt('quasiparticles',skip_header=to_skip+0, max_rows=1)
+            if(direc_sc.tolist() in dirs_C11 and (np.allclose(qpoint_sc_prev,[0,0,0]) or np.allclose(ks_path[i+1],[0,0,0]))):
+                
+                params = np.genfromtxt('quasiparticles',skip_header=to_skip+1, max_rows=3)
+                omegas  = params[0,:]
+                
+                ##==============================================================================
+                ## C11
+                print('===========================')
+                print('C11')
+                freqs = []
+                eigvecs_acou = eigvec_q[:,0:3]
+                for j in range(0,3):
+                    freqs.append(omegas[j])
+                    
+                csi = np.linalg.norm(np.dot(Hk,qpoint))
+                print('csi: ', csi)
+                j = -1
+                freq = freqs[j]
+                eigvec = eigvecs_acou[:,j]
+                print('qpoint scaled: ', qpoint)
+                print('qpoint:', np.dot(Hk,qpoint))
+                print()
+                print('freqs: ', freqs, ' taken ', freq)
+                print('eigenvec:')
+                print(np.round(eigvec*ampl/np.sqrt(masses_for_animation),2).reshape(np.shape(Ruc)))
+                print('===========================')
+                print()
+                C11 = rho * (freq/csi)**2 *conv_factor
+                ##==============================================================================
+                
+            if(direc_sc.tolist() in dirs_C12_C44 and np.allclose(qpoint_sc_prev,[0,0,0]) or np.allclose(ks_path[i+1],[0,0,0])):
+                params = np.genfromtxt('quasiparticles',skip_header=to_skip+1, max_rows=3)
+                omegas  = params[0,:]
+                
+                #check that k = [csi, csi, 0]
+                check = [np.allclose(x,csi) for x in np.dot(Hk,qpoint)] 
+                if (check not in [[True, True, False],[True, False, True],[False, True, True]]):
+                    print('ERROR WARNING: the q point is not [csi, csi, 0] so everything is gonna be wrong')
+                
+                
+                # =============================================================================
+                # C44
+                print('===========================')
+                print('C44')
+                freqs = []
+                eigvecs_acou = eigvec_q[:,0:3]
+                for j in range(0,3):
+                    freqs.append(omegas[j])
+                #csi = np.linalg.norm(np.dot(hr,qpoint_scaled))
+                j = 1
+                freq = freqs[j]
+                eigvec = eigvecs_acou[:,j]
+                print('qpoint scaled: ', qpoint)
+                print('qpoint:', np.dot(Hk,qpoint))
+                print()
+                print('freqs: ', freqs, ' taken ', freq)
+                print('eigenvec:')
+                print(np.round(eigvec*ampl/np.sqrt(masses_for_animation),2).reshape(np.shape(Ruc)))
+                print('===========================')
+                print()
+                C44 = .5* rho * (freq/csi)**2 *conv_factor
+                # =============================================================================
+                
+                #==============================================================================
+                # C12
+                print('===========================')
+                print('C12')
+                freqs = []
+                eigvecs_acou = eigvec_q[:,0:3]
+                for j in range(0,3):
+                    freqs.append(omegas[j])
+                    
+                #csi = np.linalg.norm(np.dot(hr,qpoint_scaled))
+                j = -1
+                freq = freqs[j]
+                eigvec = eigvecs_acou[:,j]
+                print('qpoint: ', qpoint)
+                print('qpoint:', np.dot(Hk,qpoint))
+                print()
+                print('freqs: ', freqs, ' taken ', freq)
+                print('eigenvec:')
+                print(np.round(eigvec*ampl/np.sqrt(masses_for_animation),2).reshape(np.shape(Ruc)))
+                print('===========================')
+                print()
+                A = rho * (freq/csi)**2 *conv_factor
+                C12 = A - C11 -2*C44 #C11-A  <- with freqs[0]
+                #==============================================================================
+                
+                print()
+                print('Elastic constants')
+                print('C11 = ', np.round(C11,2), 'GPa')
+                print('C44 = ', np.round(C44,2), 'GPa')
+                print('C12 = ', np.round(C12,2), 'GPa')
+                
+                print()
+                print('Engineering elastic constants')
+                ni = C12/(C11+C12)
+                E = C11*(1+ni)*(1-2*ni)/(1-ni)
+                print('E = ', np.round(E,2), 'GPa')
+                print('ni = ', np.round(ni,2))
+                print('G = ', np.round(C44,2), 'GPa')
+        
         
 
         
